==> listerola-0.0.0.tar.gz: listerola-0.0.0/src/main.cpp <==
//  Copyright (C) 2010 Ben Asselstine
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
//  02110-1301, USA.

#include <assert.h>
#include <memory>
#include <iostream>
#include <assert.h>
#include <glib.h>
#include <gtkmm/main.h>
#include "timing.h"
#include "file.h"

#include "main.h"

struct Main::Impl
{
    std::auto_ptr<Gtk::Main> gtk_main;
    sigc::connection on_timer_registered(Timing::timer_slot s, 
                                         int msecs_interval);

};


static Main *singleton;

Main::Main(int &argc, char **&argv)
    : impl(new Impl)
{
    singleton = this;

    Glib::thread_init();
    try
    {
	impl->gtk_main.reset(new Gtk::Main(argc, argv));

	g_set_application_name("listerola - channel listing scroller");
                
        Timing::instance().timer_registered.connect
          (sigc::mem_fun(*impl, &Main::Impl::on_timer_registered));

    }
    catch (const Glib::Error &ex) {
	std::cerr << ex.what() << std::endl;
    }
}
sigc::connection Main::Impl::on_timer_registered(Timing::timer_slot s, 
                                                 int msecs_interval)
{
      return Glib::signal_timeout().connect(s, msecs_interval);
}

Main::~Main()
{
    delete impl;
    singleton = 0;
}

Main &Main::instance()
{
    assert(singleton != 0);
    return *singleton;
}

bool Main::iterate_main_loop()
{
    try
    {
	impl->gtk_main->iteration(false);
    }
    catch (const Glib::Error &ex) {
	std::cerr << ex.what() << std::endl;
    }

    return true;
}

#include "listerola-window.h"
void Main::start_main_loop()
{
    try
    {
      ListerolaWindow w("listings.xml", 12, 3.5, 30.0, 500, 0.5, 5.0, "", 1, 40, 320, 50);
      //ListerolaWindow w("listings.xml", 5, 1.5, 100.0, 1000, 0.5, 5.0, File::get_data_path() + "/ad.jpg", 1, 50, ListerolaWindow::SCROLL_INCREMENTALLY_UP, 320, 40);
      w.run();
      impl->gtk_main->run(*w.get_window());
    }
    catch (const Glib::Error &ex) {
	std::cerr << ex.what() << std::endl;
    }
}

void Main::stop_main_loop()
{
    try
    {
	impl->gtk_main->quit();
    }
    catch (const Glib::Error &ex) {
	std::cerr << ex.what() << std::endl;
    }
}

==> listerola-0.0.1.tar.gz: listerola-0.0.1/src/main.cpp <==
//  Copyright (C) 2010 Ben Asselstine
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
//  02110-1301, USA.

#include <assert.h>
#include <memory>
#include <iostream>
#include <assert.h>
#include <glib.h>
#include <gtkmm/main.h>
#include "timing.h"
#include "file.h"

#include "listerola-window.h"
#include "listerola.h"
#include "main.h"

struct Main::Impl
{
    std::auto_ptr<Gtk::Main> gtk_main;
    sigc::connection on_timer_registered(Timing::timer_slot s, 
                                         int msecs_interval);

};

static Main *singleton;

Main::Main(int &argc, char **&argv)
    : impl(new Impl)
{
    singleton = this;

    Glib::thread_init();
    try
    {
	impl->gtk_main.reset(new Gtk::Main(argc, argv));

	g_set_application_name("listerola - channel listing scroller");
                
        Timing::instance().timer_registered.connect
          (sigc::mem_fun(*impl, &Main::Impl::on_timer_registered));

    }
    catch (const Glib::Error &ex) {
	std::cerr << ex.what() << std::endl;
    }
}
sigc::connection Main::Impl::on_timer_registered(Timing::timer_slot s, 
                                                 int msecs_interval)
{
      return Glib::signal_timeout().connect(s, msecs_interval);
}

Main::~Main()
{
    delete impl;
    singleton = 0;
}

Main &Main::instance()
{
    assert(singleton != 0);
    return *singleton;
}

bool Main::iterate_main_loop()
{
    try
    {
	impl->gtk_main->iteration(false);
    }
    catch (const Glib::Error &ex) {
	std::cerr << ex.what() << std::endl;
    }

    return true;
}

void Main::start_main_loop()
{
    try
    {
      Listerola l("listings.xml", 3.5, 0.5);
      ListerolaWindow w(l, 12, 30.0, 500, 5.0, "", 1, 40, 320, 50);
      w.run();
      impl->gtk_main->run(*w.get_window());
    }
    catch (const Glib::Error &ex) {
	std::cerr << ex.what() << std::endl;
    }
}

void Main::stop_main_loop()
{
    try
    {
	impl->gtk_main->quit();
    }
    catch (const Glib::Error &ex) {
	std::cerr << ex.what() << std::endl;
    }
}
